/*
 * Copyright (c) 2016-2019 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice and this list of conditions.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice and  this list of  conditions in the  documentation and/or
 *      other materials provided with the distribution.
 *
 *                                      Anthony Mallet on Tue Aug 23 2016
 */
#include "acmrsim.h"

#include "mrsim_c_types.h"
#include "codels.h"

/* --- Function set_rotors ---------------------------------------------- */

/** Codel mrsim_set_rotors of function set_rotors.
 *
 * Returns genom_ok.
 * Throws mrsim_e_sys.
 */
genom_event
mrsim_set_rotors(uint16_t n, mrsim_ids_simstate_s_motor_s motor[8],
                 const genom_context self)
{
  size_t i;

  if (n > or_rotorcraft_max_rotors) {
    errno = EDOM;
    return mrsim_e_sys_error("set_rotors", self);
  }

  for(i = 0; i < or_rotorcraft_max_rotors; i++)
    motor[i].disabled = i < n ? false : true;

  return genom_ok;
}


/* --- Function get_rotors ---------------------------------------------- */

/** Codel mrsim_get_rotors of function get_rotors.
 *
 * Returns genom_ok.
 */
genom_event
mrsim_get_rotors(uint16_t *n,
                 const mrsim_ids_simstate_s_motor_s motor[8],
                 const genom_context self)
{
  ssize_t i;

  for(i = or_rotorcraft_max_rotors - 1; i >= 0; i--)
    if (!motor[i].disabled) break;

  *n = i + 1;
  return genom_ok;
}
